==> content_synchronizer-8.x-1.1.tar.gz: content_synchronizer/src/Form/LaunchExportForm.php <==
<?php

namespace Drupal\content_synchronizer\Form;

use Drupal\content_synchronizer\Processors\BatchExportProcessor;
use Drupal\content_synchronizer\Processors\ExportEntityWriter;
use Drupal\content_synchronizer\Service\ArchiveDownloader;
use Drupal\content_synchronizer\Service\EntityExportFormBuilder;
use Drupal\Core\Form\FormBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Url;
use RedUNIT\Blackhole\Export;
use Symfony\Component\HttpFoundation\RedirectResponse;

/**
 * Launch Export Form.
 */
class LaunchExportForm extends FormBase {

  /**
   * The export entity.
   *
   * @var \Drupal\content_synchronizer\Entity\ExportEntity
   */
  protected $export;

  protected $currentUrl;

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'content_synchronizer.export.launch';
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {

    /** @var \Drupal\content_synchronizer\Entity\ImportEntity $import */
    $this->export = $form_state->getBuildInfo()['export'];

    // Entity list :
    $this->initRootEntitiesList($form);

    if (array_key_exists('entities_list', $form)) {
      $form['launch'] = [
        '#type'  => 'submit',
        '#value' => t('Launch export'),
      ];
    }

    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $entitiesToExport = $form_state->getUserInput()['entities_to_export'];
    $entitiesToExport = array_intersect_key($this->export->getEntitiesList(), array_flip($entitiesToExport));

    if (!empty($entitiesToExport)) {
      $this->currentUrl = \Drupal::request()->getRequestUri();

      $writer = new ExportEntityWriter();
      $writer->initFromId($this->export->label());

      $batchExportProcessor = new BatchExportProcessor($writer);
      $batchExportProcessor->exportEntities($entitiesToExport, [
        $this,
        'onBatchEnd'
      ]);
    }
  }

  /**
   * Callback after batch.
   */
  public function onBatchEnd($archiveUri) {
    $redirectUrl = $this->currentUrl;
    \Drupal::service(ArchiveDownloader::SERVICE_NAME)->redirectWithArchivePath($redirectUrl, $archiveUri);
  }

  /**
   * Init Root entities lists for display.
   */
  protected function initRootEntitiesList(array &$form) {
    $rootEntities = $this->getRootsEntities();

    if (!empty($rootEntities)) {
      $build = [
        '#theme'         => 'entities_list_table',
        '#entities'      => $rootEntities,
        '#checkbox_name' => 'entities_to_export[]',
        '#title'         => t('Entities to import'),
      ];

      $form['entities_list'] = $build;
    }

  }

  /**
   * Return the roots entities.
   */
  public function getRootsEntities() {
    $data = [];

    /** @var \Drupal\Core\Entity\Entity $entity */
    foreach ($this->export->getEntitiesList() as $key => $entity) {
      $data[$key] = [
        "entity_type_id" => $entity->getEntityTypeId(),
        "entity_id"      => $entity->id(),
        "label"          => ExportEntityWriter::getEntityLabel($entity),
        'edit_url'       => Url::fromRoute('entity.' . $entity->getEntityTypeId() . '.edit_form', [$entity->getEntityTypeId() => $entity->id()]),
      ];
    }

    return $data;
  }

  /**
   * Add a donwload hidden iframe.
   *
   * @param array $form
   *   The build form array.
   */
  protected function addDownloadIframe(array &$form) {
    if ($archiveUri = \Drupal::request()
      ->get(EntityExportFormBuilder::ARCHIVE_PARAMS)
    ) {
      if (file_exists($archiveUri)) {
        $form['archive'] = [
          '#type'       => 'html_tag',
          '#tag'        => 'iframe',
          '#attributes' => [
            'style' => ['display:none'],
            'src'   => file_create_url($archiveUri),
          ],
        ];
      }
    }
  }

}

==> content_synchronizer-8.x-1.7.tar.gz: content_synchronizer/src/Form/LaunchExportForm.php <==
<?php

namespace Drupal\content_synchronizer\Form;

use Drupal\content_synchronizer\Processors\BatchExportProcessor;
use Drupal\content_synchronizer\Processors\ExportEntityWriter;
use Drupal\content_synchronizer\Service\ArchiveDownloader;
use Drupal\content_synchronizer\Service\EntityExportFormBuilder;
use Drupal\Core\Form\FormBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Url;
use RedUNIT\Blackhole\Export;
use Symfony\Component\HttpFoundation\RedirectResponse;

/**
 * Launch Export Form.
 */
class LaunchExportForm extends FormBase {

  /**
   * The export entity.
   *
   * @var \Drupal\content_synchronizer\Entity\ExportEntity
   */
  protected $export;

  protected $currentUrl;

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'content_synchronizer.export.launch';
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {

    /** @var \Drupal\content_synchronizer\Entity\ImportEntity $import */
    $this->export = $form_state->getBuildInfo()['export'];

    // Entity list :
    $this->initRootEntitiesList($form);

    if (array_key_exists('entities_list', $form)) {
      $form['launch'] = [
        '#type'  => 'submit',
        '#value' => t('Launch export'),
      ];
    }

    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $entitiesToExport = $form_state->getUserInput()['entities_to_export'];
    $entitiesToExport = array_intersect_key($this->export->getEntitiesList(), array_flip($entitiesToExport));

    if (!empty($entitiesToExport)) {
      $this->currentUrl = \Drupal::request()->getRequestUri();

      $writer = new ExportEntityWriter();
      $writer->initFromId($this->export->label());

      $batchExportProcessor = new BatchExportProcessor($writer);
      $batchExportProcessor->exportEntities($entitiesToExport, [
        $this,
        'onBatchEnd'
      ]);
    }
  }

  /**
   * Callback after batch.
   */
  public function onBatchEnd($archiveUri) {
    $redirectUrl = $this->currentUrl;
    \Drupal::service(ArchiveDownloader::SERVICE_NAME)
      ->redirectWithArchivePath($redirectUrl, $archiveUri);
  }

  /**
   * Init Root entities lists for display.
   */
  protected function initRootEntitiesList(array &$form) {
    $rootEntities = $this->getRootsEntities();

    if (!empty($rootEntities)) {
      $build = [
        '#theme'         => 'entities_list_table',
        '#entities'      => $rootEntities,
        '#checkbox_name' => 'entities_to_export[]',
        '#title'         => t('Entities to import'),
        '#attached'      => [
          'library' => ['content_synchronizer/list']
        ]
      ];

      $form['entities_list'] = $build;
    }

  }

  /**
   * Return the roots entities.
   */
  public function getRootsEntities() {
    $data = [];

    /** @var \Drupal\Core\Entity\Entity $entity */
    foreach ($this->export->getEntitiesList() as $key => $entity) {
      $data[$key] = [
        "entity_type_id" => $entity->getEntityTypeId(),
        "entity_id"      => $entity->id(),
        "label"          => ExportEntityWriter::getEntityLabel($entity),
        'edit_url'       => Url::fromRoute('entity.' . $entity->getEntityTypeId() . '.edit_form', [$entity->getEntityTypeId() => $entity->id()]),
      ];
    }

    return $data;
  }

  /**
   * Add a donwload hidden iframe.
   *
   * @param array $form
   *   The build form array.
   */
  protected function addDownloadIframe(array &$form) {
    if ($archiveUri = \Drupal::request()
      ->get(EntityExportFormBuilder::ARCHIVE_PARAMS)
    ) {
      if (file_exists($archiveUri)) {
        $form['archive'] = [
          '#type'       => 'html_tag',
          '#tag'        => 'iframe',
          '#attributes' => [
            'style' => ['display:none'],
            'src'   => file_create_url($archiveUri),
          ],
        ];
      }
    }
  }

}
